@@ -13,13 +13,19 @@ public:
 	static QString capsVersion();
 	static QString IPCName();
 
+	// URLs
+	static QString getAppCastURL();
+
 	// Directories
 	static QString homeDir();
 	static QString resourcesDir();
+	static QString libDir();
 	static QString profilesDir();
 	static QString historyDir();
 	static QString vCardDir();
-	
+	static QStringList getCertificateStoreDirs();
+	static QString getCertificateStoreSaveDir();
+
 	// Namespaces
 	static QString optionsNS();
 	static QString storageNS();
