@@ -31,14 +31,11 @@
 #include <QColorGroup>
 #include <qsplitter.h>
 #include <qtimer.h>
-#include <q3header.h>
 #include <qtoolbutton.h>
 #include <qinputdialog.h>
 #include <qpointer.h>
 #include <qaction.h>
 #include <qobject.h>
-#include <q3popupmenu.h>
-#include <Q3TextDrag>
 #include <qcursor.h>
 #include <QCloseEvent>
 #include <QEvent>
@@ -52,6 +49,7 @@
 #include <QTextCursor>
 #include <QTextDocument> // for Qt::escape()
 #include <QToolTip>
+#include <QScrollBar>
 
 #include "psicon.h"
 #include "psiaccount.h"
@@ -76,7 +74,10 @@
 #include "psicontactlist.h"
 #include "accountlabel.h"
 #include "gcuserview.h"
+#include "mucreasonseditor.h"
 #include "mcmdmanager.h"
+#include "lastactivitytask.h"
+#include "psirichtext.h"
 
 #include "mcmdsimplesite.h"
 
@@ -210,7 +211,7 @@ public:
 
 	QString nickSeparator; // equals ":"
 
-	Q3PopupMenu *pm_settings;
+	QMenu *pm_settings;
 	int pending;
 	bool connecting;
 
@@ -233,23 +234,14 @@ public:
 
 public slots:
 	void addEmoticon(const PsiIcon *icon) {
-		if ( !dlg->isActiveTab() ) {
-			return;
-		}
-
-		QString text = icon->defaultText();
-
-		if (!text.isEmpty()) {
-			mle()->insert(text + " ");
-		}
+		addEmoticon(icon->defaultText());
 	}
 
 	void addEmoticon(QString text) {
-		if ( !dlg->isActiveTab() ) {
+		if ( !dlg->isActiveTab() )
 			return;
-		}
 
-		mle()->insert( text + " " );
+		PsiRichText::addEmoticon(mle(), text);
 	}
 
 	void deferredScroll() {
@@ -287,13 +279,31 @@ public slots:
 	{
 		JT_ClientVersion *version = qobject_cast<JT_ClientVersion*>(sender());
 		if (!version) {
-			dlg->appendSysMsg("Error in version getter!", false);
+			dlg->appendSysMsg(QString("No version information available for %1.").arg(version->jid().resource()) , false);
 			return;
 		}
 		dlg->appendSysMsg(QString("Version response from %1: N: %2 V: %3 OS: %4")
 			.arg(version->jid().resource(), version->name(), version->version(), version->os()), false);
 	}
 
+	void lastactivity_finished()
+	{
+		LastActivityTask *idle = (LastActivityTask *)sender();
+
+		if (!idle->success()) {
+			dlg->appendSysMsg(QString("Can't determine last activity time for %1.").arg(idle->jid().resource()), false);
+			return;
+		}
+
+		if (idle->status().isEmpty()) {
+			dlg->appendSysMsg(QString("Last activity from %1 at %2")
+				.arg(idle->jid().resource(), idle->time().toString()), false);
+		} else {
+			dlg->appendSysMsg(QString("Last activity from %1 at %2 (%3)")
+				.arg(idle->jid().resource(), idle->time().toString(), idle->status()), false);
+		}
+	}
+
 	void doSPing()
 	{
 		Jid full = dlg->jid().withResource(self);
@@ -313,7 +323,7 @@ public slots:
 	bool NickComplete(QStringList command)
 	{
 		if (command.count() > 0) {
-			QString nick = command[0].stripWhiteSpace();
+			QString nick = command[0].trimmed();
 			if ( !nick.isEmpty() ) {
 				prev_self = self;
 				self = nick;
@@ -332,7 +342,7 @@ public:
 	virtual bool mCmdTryStateTransit(MCmdStateIface *oldstate, QStringList command, MCmdStateIface *&newstate, QStringList &preset) {
 		if (oldstate->getName() == MCMDMUC) {
 			QString cmd;
-			if (command.count() > 0) cmd = command[0].lower();
+			if (command.count() > 0) cmd = command[0].toLower();
 	/*
 TODO:
 topic <topic>
@@ -353,7 +363,7 @@ join <channel>{,<channel>} [pass{,<pass>}
 				newstate = 0;
 			} else if(cmd == "nick") {
 				if (command.count() > 1) {
-					QString nick = command[1].stripWhiteSpace();
+					QString nick = command[1].trimmed();
 					// FIXME nick can't be empty....
 					prev_self = self;
 					self = nick;
@@ -370,13 +380,20 @@ join <channel>{,<channel>} [pass{,<pass>}
 				doSPing();
 				newstate = 0;
 			} else if (cmd == "version" && command.count() > 1) {
-				QString nick = command[1].stripWhiteSpace();
+				QString nick = command[1].trimmed();
 				Jid target = dlg->jid().withResource(nick);
 				JT_ClientVersion *version = new JT_ClientVersion(dlg->account()->client()->rootTask());
 				connect(version, SIGNAL(finished()), SLOT(version_finished()));
 				version->get(target);
 				version->go();
 				newstate = 0;
+			} else if (cmd == "idle" && command.count() > 1) {
+				QString nick = command[1].trimmed();
+				Jid target = dlg->jid().withResource(nick);
+				LastActivityTask *idle = new LastActivityTask(target, dlg->account()->client()->rootTask());
+				connect(idle, SIGNAL(finished()), SLOT(lastactivity_finished()));
+				idle->go();
+				newstate = 0;
 			} else if (cmd == "quote") {
 				dlg->appendSysMsg(command.join("|"), false);
 				preset = command;
@@ -398,8 +415,8 @@ join <channel>{,<channel>} [pass{,<pass>}
 		if (state->getName() == MCMDMUC) {
 			QString spaceAtEnd = QString(QChar(0));
 			if (item == 0) {
-				all << "clear" + spaceAtEnd << "nick" + spaceAtEnd << "sping" + spaceAtEnd << "version" + spaceAtEnd << "quote" + spaceAtEnd;
-			} else if (item == 1 && partcommand[0] == "version") {
+				all << "clear" + spaceAtEnd << "nick" + spaceAtEnd << "sping" + spaceAtEnd << "version" + spaceAtEnd << "idle" + spaceAtEnd << "quote" + spaceAtEnd;
+			} else if (item == 1 && (partcommand[0] == "version" || partcommand[0] == "idle")) {
 				all = dlg->ui_.lv_users->nickList();
 			}
 		}
@@ -475,12 +492,12 @@ public:
 
 		QTextCursor cursor = te_log()->textCursor();
 		cursor.beginEditBlock();
-		PsiTextView::Selection selection = te_log()->saveSelection(cursor);
+		PsiRichText::Selection selection = PsiRichText::saveSelection(te_log(), cursor);
 
 		removeTrackBar(cursor);
 		addTrackBar(cursor);
 
-		te_log()->restoreSelection(cursor, selection);
+		PsiRichText::restoreSelection(te_log(), cursor, selection);
 		cursor.endEditBlock();
 		te_log()->setTextCursor(cursor);
 
@@ -569,7 +586,7 @@ public:
 			QString postAdd = atStart_ ? nickSeparator + " " : "";
 
 			foreach(QString nick, nicks) {
-				if (nick.left(toComplete_.length()).lower() == toComplete_.lower()) {
+				if (nick.left(toComplete_.length()).toLower() == toComplete_.toLower()) {
 					suggestedNicks << nick + postAdd;
 				}
 			}
@@ -652,7 +669,7 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 	updateIdentityVisibility();
 
 	d->act_find = new IconAction(tr("Find"), "psi/search", tr("&Find"), 0, this);
-	connect(d->act_find, SIGNAL(activated()), SLOT(openFind()));
+	connect(d->act_find, SIGNAL(triggered()), SLOT(openFind()));
 	ui_.tb_find->setDefaultAction(d->act_find);
 
 	ui_.tb_emoticons->setIcon(IconsetFactory::icon("psi/smile").icon());
@@ -669,11 +686,11 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 	connect( d->act_clear, SIGNAL( activated() ), SLOT( doClearButton() ) );
 	
 	d->act_configure = new IconAction(tr("Configure Room"), "psi/configure-room", tr("&Configure Room"), 0, this);
-	connect(d->act_configure, SIGNAL(activated()), SLOT(configureRoom()));
+	connect(d->act_configure, SIGNAL(triggered()), SLOT(configureRoom()));
 
 #ifdef WHITEBOARDING
 	d->act_whiteboard = new IconAction(tr("Open a Whiteboard"), "psi/whiteboard", tr("Open a &Whiteboard"), 0, this);
-	connect(d->act_whiteboard, SIGNAL(activated()), SLOT(openWhiteboard()));
+	connect(d->act_whiteboard, SIGNAL(triggered()), SLOT(openWhiteboard()));
 #endif
 
 	connect(pa->psi()->iconSelectPopup(), SIGNAL(textSelected(QString)), d, SLOT(addEmoticon(QString)));
@@ -683,11 +700,11 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 
 	d->act_nick = new QAction(this);
 	d->act_nick->setText(tr("Change Nickname..."));
-	connect(d->act_nick, SIGNAL(activated()), d, SLOT(doNick()));
+	connect(d->act_nick, SIGNAL(triggered()), d, SLOT(doNick()));
 
 	d->act_mini_cmd = new QAction(this);
 	d->act_mini_cmd->setText(tr("Enter Command..."));
-	connect(d->act_mini_cmd, SIGNAL(activated()), d, SLOT(doMiniCmd()));
+	connect(d->act_mini_cmd, SIGNAL(triggered()), d, SLOT(doMiniCmd()));
 	addAction(d->act_mini_cmd);
 
 	ui_.toolbar->setIconSize(QSize(16,16));
@@ -703,22 +720,22 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 	// Common actions
 	d->act_send = new QAction(this);
 	addAction(d->act_send);
-	connect(d->act_send,SIGNAL(activated()), SLOT(mle_returnPressed()));
+	connect(d->act_send,SIGNAL(triggered()), SLOT(mle_returnPressed()));
 	d->act_close = new QAction(this);
 	addAction(d->act_close);
-	connect(d->act_close,SIGNAL(activated()), SLOT(close()));
+	connect(d->act_close,SIGNAL(triggered()), SLOT(close()));
 	d->act_scrollup = new QAction(this);
 	addAction(d->act_scrollup);
-	connect(d->act_scrollup,SIGNAL(activated()), SLOT(scrollUp()));
+	connect(d->act_scrollup,SIGNAL(triggered()), SLOT(scrollUp()));
 	d->act_scrolldown = new QAction(this);
 	addAction(d->act_scrolldown);
-	connect(d->act_scrolldown,SIGNAL(activated()), SLOT(scrollDown()));
+	connect(d->act_scrolldown,SIGNAL(triggered()), SLOT(scrollDown()));
 
 	ui_.mini_prompt->hide();
 	connect(ui_.mle, SIGNAL(textEditCreated(QTextEdit*)), SLOT(chatEditCreated()));
 	chatEditCreated();
 
-	d->pm_settings = new Q3PopupMenu(this);
+	d->pm_settings = new QMenu(this);
 	connect(d->pm_settings, SIGNAL(aboutToShow()), SLOT(buildMenu()));
 	ui_.tb_actions->setMenu(d->pm_settings);
 
@@ -840,7 +857,8 @@ void GCMainDlg::mucInfoDialog(const QString& title, const QString& message, cons
 		m += tr("\nReason: %1").arg(reason);
 
 	// FIXME maybe this should be queued in the future?
-	QMessageBox* msg = new QMessageBox(QMessageBox::Information, title, m, QMessageBox::Ok, this, Qt::WDestructiveClose);
+	QMessageBox* msg = new QMessageBox(QMessageBox::Information, title, m, QMessageBox::Ok, this);
+	msg->setAttribute(Qt::WA_DeleteOnClose, true);
 	msg->setModal(false);
 	msg->show();
 }
@@ -849,7 +867,7 @@ void GCMainDlg::logSelectionChanged()
 {
 #ifdef Q_WS_MAC
 	// A hack to only give the message log focus when text is selected
-	if (ui_.log->hasSelectedText()) 
+	if (ui_.log->textCursor().hasSelection()) 
 		ui_.log->setFocus();
 	else 
 		ui_.mle->chatEdit()->setFocus();
@@ -899,7 +917,7 @@ void MiniCommand_Depreciation_Message(const QString &old,const QString &newCmd,
 void GCMainDlg::mle_returnPressed()
 {
 	d->tabCompletion.reset();
-	QString str = d->mle()->text();
+	QString str = d->mle()->toPlainText();
 
 	if (d->mCmdSite.isActive()) {
 		if (!d->mCmdManager.processCommand(str)) {
@@ -925,8 +943,8 @@ void GCMainDlg::mle_returnPressed()
 		return;
 	}
 
-	if(str.lower().startsWith("/nick ")) {
-		QString nick = str.mid(6).stripWhiteSpace();
+	if(str.toLower().startsWith("/nick ")) {
+		QString nick = str.mid(6).trimmed();
     XMPP::Jid newJid = jid().withResource(nick);
 		if (!nick.isEmpty() && newJid.isValid()) {
 			d->prev_self = d->self;
@@ -978,10 +996,10 @@ void GCMainDlg::le_downPressed()
 void GCMainDlg::doTopic()
 {
 	bool ok = false;
-	QString str = QInputDialog::getText(
+	QString str = QInputDialog::getText(this,
 		tr("Set Groupchat Topic"),
 		tr("Enter a topic:"),
-		QLineEdit::Normal, ui_.le_topic->text(), &ok, this);
+		QLineEdit::Normal, ui_.le_topic->text(), &ok);
 
 	if(ok) {
 		Message m(jid());
@@ -1086,7 +1104,8 @@ void GCMainDlg::goConn()
 
 void GCMainDlg::dragEnterEvent(QDragEnterEvent *e)
 {
-	e->accept(e->mimeData()->hasText());
+	if (e->mimeData()->hasText())
+		e->accept();
 }
 
 void GCMainDlg::dropEvent(QDropEvent *e)
@@ -1457,7 +1476,7 @@ void GCMainDlg::updateLastMsgTime(QDateTime t)
 	bool doInsert = t.date() != lastMsgTime_.date();
 	lastMsgTime_ = t;
 	if (doInsert) {
-		QString color = "#00A000";
+		QString color = PsiOptions::instance()->getOption("options.ui.look.colors.messages.informational").toString();
 		ui_.log->appendText(QString("<font color=\"%1\">*** %2</font>").arg(color).arg(t.date().toString(Qt::ISODate)));
 	}
 }
@@ -1476,7 +1495,8 @@ void GCMainDlg::appendSysMsg(const QString &str, bool alert, const QDateTime &ts
 
 	updateLastMsgTime(time);
 	QString timestr = ui_.log->formatTimeStamp(time);
-	ui_.log->appendText(QString("<font color=\"#00A000\">[%1]").arg(timestr) + QString(" *** %1</font>").arg(Qt::escape(str)));
+	QString color = PsiOptions::instance()->getOption("options.ui.look.colors.messages.informational").toString();
+	ui_.log->appendText(QString("<font color=\"%1\">[%2]").arg(color, timestr) + QString(" *** %1</font>").arg(Qt::escape(str)));
 
 	if(alert)
 		doAlert();
@@ -1528,14 +1548,15 @@ void GCMainDlg::appendMessage(const Message &m, bool alert)
 		color = "#0000FF";
 	}*/
 	nickcolor = getNickColor(who);
-	textcolor = ui_.log->palette().active().text().name();
+	textcolor = ui_.log->palette().windowText().color().name();
 	if(alert) {
 		textcolor = "#FF0000";
 		alerttagso = "<b>";
 		alerttagsc = "</b>";
 	}
-	if(m.spooled())
-		nickcolor = "#008000"; //color = "#008000";
+	if(m.spooled()) {
+		nickcolor = PsiOptions::instance()->getOption("options.ui.look.colors.messages.informational").toString();
+	}
 
 	QString timestr = ui_.log->formatTimeStamp(m.timeStamp());
 
@@ -1628,7 +1649,7 @@ void GCMainDlg::setLooks()
 	ui_.mle->chatEdit()->setFont(f);
 
 	f.fromString(PsiOptions::instance()->getOption("options.ui.look.font.contactlist").toString());
-	ui_.lv_users->Q3ListView::setFont(f);
+	ui_.lv_users->setFont(f);
 
 	if (PsiOptions::instance()->getOption("options.ui.chat.central-toolbar").toBool()) {
 		ui_.toolbar->show();
@@ -1712,6 +1733,32 @@ void GCMainDlg::lv_action(const QString &nick, const Status &s, int x)
 		if (contact->s.mucItem().role() != MUCItem::Moderator)
 			d->mucManager->setRole(nick, MUCItem::Moderator);
 	}
+	else if(x >= 100 && x<300) {
+		// Kick || Ban with reason
+		QString reason;
+		QStringList reasons = PsiOptions::instance()->getOption("options.muc.reasons").toStringList();
+		if (x==100 || x==200) {
+			// Show custom reason dialog
+			MUCReasonsEditor *editor=new MUCReasonsEditor(this);
+			if (editor->exec())
+				reason=editor->reason();
+			delete editor;
+		} else {
+			int idx = (x<200) ? x-101 : x-201;
+			if (idx<reasons.count())
+				reason=reasons[idx];
+		}
+		if (!reason.isEmpty()) {
+			if (x<200)
+				d->mucManager->kick(nick, reason);
+			else {
+				GCUserViewItem *contact = (GCUserViewItem*) ui_.lv_users->findEntry(nick);
+				if (!contact) return;
+				d->mucManager->ban(contact->s.mucItem().jid(), reason);
+			}
+		}
+
+	}
 	/*else if(x == 15) {
 		GCUserViewItem *contact = (GCUserViewItem*) ui_.lv_users->findEntry(nick);
 		if (contact->s.mucItem().affiliation() != MUCItem::NoAffiliation)
@@ -1749,10 +1796,10 @@ void GCMainDlg::buildMenu()
 #ifdef WHITEBOARDING
 	d->act_whiteboard->addTo( d->pm_settings );
 #endif
-	d->pm_settings->insertSeparator();
+	d->pm_settings->addSeparator();
 
-	d->act_icon->addTo( d->pm_settings );
-	d->act_nick->addTo( d->pm_settings );
+	d->pm_settings->addAction(d->act_icon);
+	d->pm_settings->addAction(d->act_nick);
 }
 
 void GCMainDlg::chatEditCreated()
@@ -1781,13 +1828,15 @@ int GCMainDlg::unreadMessageCount() const
 //----------------------------------------------------------------------------
 // GCFindDlg
 //----------------------------------------------------------------------------
-GCFindDlg::GCFindDlg(const QString &str, QWidget *parent, const char *name)
-	: QDialog(parent, name, false)
+GCFindDlg::GCFindDlg(const QString& str, QWidget* parent)
+	: QDialog(parent)
 {
 	setAttribute(Qt::WA_DeleteOnClose);
 	setWindowTitle(tr("Find"));
-	QVBoxLayout *vb = new QVBoxLayout(this, 4);
-	QHBoxLayout *hb = new QHBoxLayout(vb);
+	QVBoxLayout *vb = new QVBoxLayout(this);
+	vb->setMargin(4);
+	QHBoxLayout *hb = new QHBoxLayout;
+	vb->addLayout(hb);
 	QLabel *l = new QLabel(tr("Find:"), this);
 	hb->addWidget(l);
 	le_input = new QLineEdit(this);
@@ -1800,7 +1849,8 @@ GCFindDlg::GCFindDlg(const QString &str, QWidget *parent, const char *name)
 	Line1->setFrameShape( QFrame::HLine );
 	vb->addWidget(Line1);
 
-	hb = new QHBoxLayout(vb);
+	hb = new QHBoxLayout;
+	vb->addLayout(hb);
 	hb->addStretch(1);
 	QPushButton *pb_close = new QPushButton(tr("&Close"), this);
 	connect(pb_close, SIGNAL(clicked()), SLOT(close()));
