@@ -48,7 +48,7 @@ QString JIDUtil::encode(const QString &jid)
 		else if(!jid.at(n).isLetterOrNumber()) {
 			// hex encode
 			QString hex;
-			hex.sprintf("%%%02X", jid.at(n).latin1());
+			hex.sprintf("%%%02X", jid.at(n).toLatin1());
 			jid2.append(hex);
 		}
 		else {
