@@ -39,6 +39,7 @@
 #include <time.h>
 #include "profiledlg.h"
 #include "activeprofiles.h"
+#include "psicli.h"
 #include "psioptions.h"
 
 #include "eventdlg.h"
@@ -79,9 +80,10 @@
 
 using namespace XMPP;
 
-PsiMain::PsiMain(const QString& uriToOpen, QObject *par)
+
+PsiMain::PsiMain(const QMap<QString, QString>& commandline, QObject *par)
 	: QObject(par)
-	, uri(uriToOpen)
+	, cmdline(commandline)
 {
 	pcon = 0;
 
@@ -98,13 +100,30 @@ PsiMain::PsiMain(const QString& uriToOpen, QObject *par)
 
 
 	if(lastLang.isEmpty()) {
-		lastLang = QTextCodec::locale();
+		lastLang = QLocale::system().name().section('_', 0, 0);
 		//printf("guessing locale: [%s]\n", lastLang.latin1());
 	}
 
 	TranslationManager::instance()->loadTranslation(lastLang);
 
-	if(autoOpen && !lastProfile.isEmpty() && profileExists(lastProfile)) {
+	if (cmdline.contains("help")) {
+		PsiCli().showHelp();
+		QTimer::singleShot(0, this, SLOT(bail()));
+	}
+	else if(cmdline.contains("version")) {
+		PsiCli().showVersion();
+		QTimer::singleShot(0, this, SLOT(bail()));
+	}
+	else if(cmdline.contains("choose-profile")) {
+		// Select a profile
+		QTimer::singleShot(0, this, SLOT(chooseProfile()));
+	}
+	else if(cmdline.contains("profile") && profileExists(cmdline["profile"])) {
+		// Open profile from commandline
+		activeProfile = lastProfile = cmdline["profile"];
+		QTimer::singleShot(0, this, SLOT(sessionStart()));
+	}
+	else if(autoOpen && !lastProfile.isEmpty() && profileExists(lastProfile)) {
 		// Auto-open the last profile
 		activeProfile = lastProfile;
 		QTimer::singleShot(0, this, SLOT(sessionStart()));
@@ -184,7 +203,7 @@ void PsiMain::chooseProfile()
 					QPushButton *activate = mb.addButton(tr("Activate"), QMessageBox::AcceptRole);
 					mb.exec();
 					if (mb.clickedButton() == activate) {
-						ActiveProfiles::instance()->raiseOther(str, true);
+						ActiveProfiles::instance()->raise(str, true);
 						quit();
 						return;
 					}
@@ -214,7 +233,7 @@ void PsiMain::chooseProfile()
 void PsiMain::sessionStart()
 {
 	if (!ActiveProfiles::instance()->setThisProfile(activeProfile)) { // already running
-		if (!ActiveProfiles::instance()->raiseOther(activeProfile, true)) {
+		if (!ActiveProfiles::instance()->raise(activeProfile, true)) {
 			QMessageBox::critical(0, tr("Error"), tr("Cannot open this profile - it is already running, but not responding"));
 		}
 		quit();
@@ -232,9 +251,15 @@ void PsiMain::sessionStart()
 		return;
 	}
 	connect(pcon, SIGNAL(quit(int)), SLOT(sessionQuit(int)));
-	if (!uri.isEmpty()) {
-		pcon->doOpenUri(uri);
-		uri.clear();
+
+	if (cmdline.contains("uri")) {
+		ActiveProfiles::instance()->openUriRequested(cmdline.value("uri"));
+		cmdline.remove("uri");
+	}
+	if (cmdline.contains("status") || cmdline.contains("status-message")) {
+		ActiveProfiles::instance()->setStatusRequested(cmdline.value("status"), cmdline.value("status-message"));
+		cmdline.remove("status");
+		cmdline.remove("status-message");
 	}
 }
 
@@ -356,6 +381,8 @@ static int restart_process(int argc, char **argv, const QByteArray &uri)
 }
 #endif
 
+
+
 int main(int argc, char *argv[])
 {
 	// If Psi runs as uri handler the commandline might contain
@@ -368,39 +395,18 @@ int main(int argc, char *argv[])
 	// see http://www.mozilla.org/security/announce/2007/mfsa2007-23.html
 	// for how this problem affected firefox on windows.
 
-	QByteArray uriBA;
-	for (int i=1; i<argc; i++) {
-		QByteArray str = QByteArray(argv[i]);
-		QByteArray var, val;
-		int x = str.find('=');
-		if(x == -1) {
-			var = str;
-			val = "";
-		} else {
-			var = str.mid(0,x);
-			val = str.mid(x+1);
-		}
+	PsiCli cli;
 
-		if (var == "--uri") {
-			uriBA = val;
-			if (uriBA.isEmpty() && i+1 < argc) {
-				uriBA = QByteArray(argv[i+1]);
-			}
+	QMap<QString, QString> cmdline = cli.parse(argc, argv, QStringList() << "uri", &argc);
 
-			// terminate args here. Everything that follows mustn't
-			// be availible in later commandline scanning.
+	if (cmdline.contains("uri")) {
 #ifdef URI_RESTART
-			// for windows, we have to do this by restarting the
-			// process
-			return restart_process(i, argv, uriBA);
+		// for windows, we have to restart the process
+		return restart_process(argc, argv, cmdline["uri"].toLocal8Bit());
 #else
-			// otherwise, it should enough to modify argc/argv
-			argc = i;
-			argv[i] = 0;
-			break;
+		// otherwise, it should enough to modify argc/argv
+		argv[argc] = 0;
 #endif
-		}
-		
 	}
 
 	// NOTE: Qt 4.5 compatibility note: please don't move this call.
@@ -433,13 +439,7 @@ int main(int argc, char *argv[])
 	keystoremgr.waitForBusyFinished(); // FIXME get rid of this
 
 #ifdef USE_CRASH
-	int useCrash = true;
-	int i;
-	for(i = 1; i < argc; ++i) {
-		QString str = argv[i];
-		if ( str == "--nocrash" )
-			useCrash = false;
-	}
+	int useCrash = !cmdline.contains("nocrash");
 
 	if ( useCrash )
 		Crash::registerSigsegvHandler(argv[0]);
@@ -450,38 +450,39 @@ int main(int argc, char *argv[])
 
 	//dtcp_port = 8000;
 
-	QString uri = QString::fromLocal8Bit(uriBA);
-	for(int n = 1; n < argc; ++n) {
-		QString str = argv[n];
-		QString var, val;
-		int x = str.find('=');
-		if(x == -1) {
-			var = str;
-			val = "";
-		}
-		else {
-			var = str.mid(0,x);
-			val = str.mid(x+1);
-		}
-
 #ifdef URI_RESTART
-		if(var == "--encuri")
-			uri = decodeUri(val);
+	if (cmdline.contains("encuri")) {
+		cmdline["uri"] = decodeUri(cmdline["encuri"].toLocal8Bit());
+		cmdline.remove("encuri");
+	}
 #endif
-		//if(var == "--no-gpg")
-		//	use_gpg = false;
-		//else if(var == "--no-gpg-agent")
-		//	no_gpg_agent = true;
-		//else if(var == "--linktest")
-		//	link_test = true;
+
+	// check if we want to remote-control other psi instance
+	if (!cmdline.contains("help") && !cmdline.contains("version") && !cmdline.contains("choose-profile")
+		&& ActiveProfiles::instance()->isAnyActive()
+		&& ((cmdline.contains("profile") && ActiveProfiles::instance()->isActive(cmdline["profile"])) || !cmdline.contains("profile"))) {
+
+		bool raise = true;
+		if (cmdline.contains("uri")) {
+			ActiveProfiles::instance()->openUri(cmdline.value("profile"), cmdline.value("uri"));
+			raise = false;
+		}
+		if (cmdline.contains("status")) {
+			ActiveProfiles::instance()->setStatus(cmdline.value("profile"), cmdline.value("status"), cmdline.value("status-message"));
+			raise = false;
+		}
+
+		if (raise) {
+			ActiveProfiles::instance()->raise(cmdline.value("profile"), true);
+		}
+		return 0;
 	}
 
-	if (!uri.isEmpty()) {
-		if (ActiveProfiles::instance()->sendOpenUri(uri)) {
-			return 0;
-		}
+	if (cmdline.contains("remote")) {
+		return 0;
 	}
 
+
 	//if(link_test)
 	//	printf("Link test enabled\n");
 
@@ -496,7 +497,7 @@ int main(int argc, char *argv[])
 	//if(!QCA::isSupported(QCA::CAP_SHA1))
 	//	QCA::insertProvider(XMPP::createProviderHash());
 
-	PsiMain *psi = new PsiMain(uri);
+	PsiMain *psi = new PsiMain(cmdline);
 	QObject::connect(psi, SIGNAL(quit()), &app, SLOT(quit()));
 	int returnValue = app.exec();
 	delete psi;
