@@ -23,6 +23,7 @@
 
 #include <QString>
 #include <QObject>
+#include <QMap>
 
 class PsiCon;
 
@@ -30,7 +31,7 @@ class PsiMain : public QObject
 {
 	Q_OBJECT
 public:
-	PsiMain(const QString& uriToOpen, QObject *parent=0);
+	PsiMain(const QMap<QString, QString>& commandline, QObject *parent=0);
 	~PsiMain();
 
 signals:
@@ -45,7 +46,7 @@ private slots:
 private:
 	QString lastProfile, lastLang;
 	bool autoOpen;
-	QString uri;
+	QMap<QString, QString> cmdline;
 
 	PsiCon *pcon;
 };
