@@ -21,27 +21,20 @@
 #ifndef PASSPHRASEDLG_H
 #define PASSPHRASEDLG_H
 
-#include"ui_passphrase.h"
+#include "ui_passphrase.h"
 
-class PassphraseDlg : public PassphraseUI
+class PassphraseDlg : public QDialog
 {
 	Q_OBJECT
 public:
-	PassphraseDlg(QWidget *parent=0, const char *name=0);
-	~PassphraseDlg();
+	PassphraseDlg(QWidget* parent = 0);
 
-	QString passphrase() const;
-	void unblock();
+	void promptPassphrase(const QString& name);
 
-signals:
-	void submitPassphrase(const QString &);
-	void rejectPassphrase();
+	QString getPassphrase() const;
 
-public slots:
-	void reject();
-
-private slots:
-	void doOK();
+private:
+	Ui::Passphrase ui_;
 };
 
 #endif
