@@ -24,13 +24,17 @@ public:
 	static PGPUtil& instance();
 
 	bool pgpAvailable();
+	void clearPGPAvailableCache();
+
+	static void showDiagnosticText(const QString& event, const QString& diagnostic);
+	static void showDiagnosticText(QCA::SecureMessage::Error error, const QString& diagnostic);
 
 	QCA::KeyStoreEntry getSecretKeyStoreEntry(const QString& key);
 	QCA::KeyStoreEntry getPublicKeyStoreEntry(const QString& key);
-	
+
 	QString stripHeaderFooter(const QString &);
 	QString addHeaderFooter(const QString &, int);
-			
+
 	QString messageErrorString(enum QCA::SecureMessage::Error);
 
 	bool equals(QCA::PGPKey, QCA::PGPKey);
@@ -67,6 +71,7 @@ private:
 	PassphraseDlg* passphraseDlg_;
 	int currentEventId_;
 	QString currentEntryId_;
+	bool cache_no_pgp_;
 
 	// FIXME
 	friend class PGPKeyDlg;
