@@ -671,21 +671,21 @@ GameBoard::GameBoard(GameType g, const QString &h, QWidget *parent,
 	drw->setEnabled(false);
 	drw->setFocusPolicy(Qt::NoFocus);
 	box = new Q3GroupBox(tr("Game chat"), this);
-	lst = new Q3ListBox(box);
+	lst = new QListWidget(box);
 	lst->setFocusPolicy(Qt::NoFocus);
 	lst->setVScrollBarMode(Q3ScrollView::AlwaysOff);
-	lst->setSelectionMode(Q3ListBox::NoSelection);
+	lst->setSelectionMode(QListWidget::NoSelection);
 	edt = new QLineEdit(box);
 	edt->setEnabled(false);
 	setFocusProxy(edt);
 	hist = new Q3GroupBox(tr("History"), this);
 	hist->setAlignment(Qt::AlignHCenter);
 	hist->setFocusPolicy(Qt::NoFocus);
-	hw = new Q3ListBox(hist);
-	hw->setSelectionMode(Q3ListBox::NoSelection);
+	hw = new QListWidget(hist);
+	hw->setSelectionMode(QListWidget::NoSelection);
 	hw->setPaletteBackgroundColor(cw);
-	hb = new Q3ListBox(hist);
-	hb->setSelectionMode(Q3ListBox::NoSelection);
+	hb = new QListWidget(hist);
+	hb->setSelectionMode(QListWidget::NoSelection);
 	hb->setPaletteBackgroundColor(cb);
 	//tmr = new QTimer(this);
 	//sock_tout = SOCK_WAIT;
@@ -747,20 +747,20 @@ GameBoard::GameBoard(int sfd, QWidget *parent, const char *name)
 	drw->setEnabled(false);
 	drw->setFocusPolicy(Qt::NoFocus);
 	box = new Q3GroupBox(tr("Game chat"), this);
-	lst = new Q3ListBox(box);
+	lst = new QListWidget(box);
 	lst->setFocusPolicy(Qt::NoFocus);
 	lst->setVScrollBarMode(Q3ScrollView::AlwaysOff);
-	lst->setSelectionMode(Q3ListBox::NoSelection);
+	lst->setSelectionMode(QListWidget::NoSelection);
 	edt = new QLineEdit(box);
 	setFocusProxy(edt);
 	hist = new Q3GroupBox(tr("History"), this);
 	hist->setAlignment(Qt::AlignHCenter);
 	hist->setFocusPolicy(Qt::NoFocus);
-	hw = new Q3ListBox(hist);
-	hw->setSelectionMode(Q3ListBox::NoSelection);
+	hw = new QListWidget(hist);
+	hw->setSelectionMode(QListWidget::NoSelection);
 	hw->setPaletteBackgroundColor(cw);
-	hb = new Q3ListBox(hist);
-	hb->setSelectionMode(Q3ListBox::NoSelection);
+	hb = new QListWidget(hist);
+	hb->setSelectionMode(QListWidget::NoSelection);
 	hb->setPaletteBackgroundColor(cb);
 	
 	//sock->setSocket(sfd);
