@@ -23,8 +23,6 @@
  *
  */
 
-#include <QtCore>
-
 #include "psiplugin.h"
 
 class NullPlugin : public QObject, public PsiPlugin
@@ -33,7 +31,12 @@ class NullPlugin : public QObject, public PsiPlugin
 	Q_INTERFACES(PsiPlugin)
 
 public:
-	virtual QString name() const; 
+	virtual QString name() const;
+	virtual QString shortName() const;
+	virtual QString version() const;
+	virtual QWidget* options() const;
+	virtual bool enable();
+	virtual bool disable();
 };
 
 Q_EXPORT_PLUGIN(NullPlugin);
@@ -43,4 +46,29 @@ QString NullPlugin::name() const
 	return "Null Plugin";
 }
 
+QString NullPlugin::shortName() const
+{
+	return "null";
+}
+
+QString NullPlugin::version() const
+{
+	return "0.1";
+}
+
+QWidget* NullPlugin::options() const
+{
+	return 0;
+}
+
+bool NullPlugin::enable()
+{
+	return true;
+}
+
+bool NullPlugin::disable()
+{
+	return true;
+}
+
 #include "nullplugin.moc"
