@@ -21,7 +21,7 @@
 #ifndef PSIACTIONS_H
 #define PSIACTIONS_H
 
-typedef enum ActivationType {
+enum ActivationType {
 	UserAction = 0,
 	IncomingStanza,
 	FromXml
