@@ -20,7 +20,6 @@
 
 #include "psicon.h"
 
-#include <q3ptrlist.h>
 #include <qapplication.h>
 #include <qdesktopwidget.h>
 #include <QMenuBar>
@@ -114,13 +113,13 @@ class PsiConObject : public QObject
 	Q_OBJECT
 public:
 	PsiConObject(QObject *parent)
-	: QObject(parent, "PsiConObject")
+	: QObject(parent)
 	{
 		QDir p(ApplicationInfo::homeDir());
 		QDir v(ApplicationInfo::homeDir() + "/tmp-sounds");
 		if(!v.exists())
 			p.mkdir("tmp-sounds");
-		Iconset::setSoundPrefs(v.absPath(), this, SLOT(playSound(QString)));
+		Iconset::setSoundPrefs(v.absolutePath(), this, SLOT(playSound(QString)));
 		connect(URLObject::getInstance(), SIGNAL(openURL(QString)), SLOT(openURL(QString)));
 	}
 
@@ -235,12 +234,8 @@ private slots:
 	void updateIconSelect()
 	{
 		Iconset iss;
-		Q3PtrListIterator<Iconset> iconsets(PsiIconset::instance()->emoticons);
-		Iconset *iconset;
-		while ( (iconset = iconsets.current()) != 0 ) {
+		foreach(Iconset* iconset, PsiIconset::instance()->emoticons) {
 			iss += *iconset;
-
-			++iconsets;
 		}
 
 		iconSelect->setIconset(iss);
@@ -443,7 +438,7 @@ bool PsiCon::init()
 	Anim::setMainThread(QThread::currentThread());
 
 	// setup the main window
-	d->mainwin = new MainWin(PsiOptions::instance()->getOption("options.ui.contactlist.always-on-top").toBool(), (PsiOptions::instance()->getOption("options.ui.systemtray.enable").toBool() && PsiOptions::instance()->getOption("options.contactlist.use-toolwindow").toBool()), this, "psimain"); 
+	d->mainwin = new MainWin(PsiOptions::instance()->getOption("options.ui.contactlist.always-on-top").toBool(), (PsiOptions::instance()->getOption("options.ui.systemtray.enable").toBool() && PsiOptions::instance()->getOption("options.contactlist.use-toolwindow").toBool()), this); 
 	d->mainwin->setUseDock(PsiOptions::instance()->getOption("options.ui.systemtray.enable").toBool());
 
 	connect(d->mainwin, SIGNAL(closeProgram()), SLOT(closeProgram()));
@@ -579,10 +574,12 @@ bool PsiCon::init()
 	addPsiConAdapter(this);
 #endif
 
-	connect(ActiveProfiles::instance(), SIGNAL(raiseMainWindow()), SLOT(raiseMainwin()));
-	connect(ActiveProfiles::instance(), SIGNAL(openUri(const QUrl &)), SLOT(doOpenUri(const QUrl &)));
+	connect(ActiveProfiles::instance(), SIGNAL(setStatusRequested(const QString &, const QString &)), SLOT(setStatusFromCommandline(const QString &, const QString &)));
+	connect(ActiveProfiles::instance(), SIGNAL(openUriRequested(const QString &)), SLOT(openUri(const QString &)));
+	connect(ActiveProfiles::instance(), SIGNAL(raiseRequested()), SLOT(raiseMainwin()));
 
-	DesktopUtil::setUrlHandler("xmpp", this, "doOpenUri");
+
+	DesktopUtil::setUrlHandler("xmpp", this, "openUri");
 
 	if(AvCallManager::isSupported()) {
 		options_avcall_update();
@@ -704,8 +701,15 @@ void PsiCon::changeProfile()
 {
 	ActiveProfiles::instance()->unsetThisProfile();
 	if(d->contactList->haveActiveAccounts()) {
-		QMessageBox::information(0, CAP(tr("Error")), tr("Please disconnect before changing the profile."));
-		return;
+		QMessageBox messageBox(QMessageBox::Information, CAP(tr("Error")), tr("Please disconnect before changing the profile."));
+		QPushButton* cancel = messageBox.addButton(QMessageBox::Cancel);
+		QPushButton* disconnect = messageBox.addButton(tr("&Disconnect"), QMessageBox::AcceptRole);
+		messageBox.setDefaultButton(disconnect);
+		messageBox.exec();
+		if (messageBox.clickedButton() == cancel)
+			return;
+
+		setStatusFromDialog(XMPP::Status::Offline, false);
 	}
 
 	quit(QuitProfile);
@@ -796,7 +800,7 @@ void PsiCon::dialogRegister(QWidget *w)
 {
 	item_dialog *i = new item_dialog;
 	i->widget = w;
-	i->className = w->className();
+	i->className = w->metaObject()->className();
 	d->dialogList.append(i);
 }
 
@@ -893,6 +897,15 @@ void PsiCon::setStatusFromDialog(const Status &s, bool withPriority)
 	setGlobalStatus(s, withPriority);
 }
 
+void PsiCon::setStatusFromCommandline(const QString &status, const QString &message)
+{
+	PsiOptions::instance()->setOption("options.status.last-message", message);
+	XMPP::Status s;
+	s.setType(status);
+	s.setStatus(message);	// yes, a bit different naming convention..
+	setGlobalStatus(s, false);
+}
+
 void PsiCon::setGlobalStatus(const Status &s,  bool withPriority)
 {
 	// Check whether all accounts are logged off
@@ -988,9 +1001,16 @@ void PsiCon::checkAccountsEmpty()
 	}
 }
 
-void PsiCon::doOpenUri(const QUrl &uri)
+void PsiCon::openUri(const QString &uri)
 {
-	qDebug() << "uri:  " << uri.toString();
+	QUrl url;
+	url.setEncodedUrl(uri.toLatin1());
+	openUri(url);
+}
+
+void PsiCon::openUri(const QUrl &uri)
+{
+	//qDebug() << "uri:  " << uri.toString();
 
 	// scheme
 	if (uri.scheme() != "xmpp") {
@@ -1081,10 +1101,10 @@ void PsiCon::optionChanged(const QString& option)
 
 void PsiCon::slotApplyOptions()
 {
-	PsiOptions *o = PsiOptions::instance();
 	PsiIconset::instance()->reloadRoster();
 
 #ifndef Q_WS_MAC
+	PsiOptions *o = PsiOptions::instance();
 	if (!PsiOptions::instance()->getOption("options.ui.contactlist.show-menubar").toBool()) {
 		// check if all toolbars are disabled
 		bool toolbarsVisible = false;
@@ -1197,11 +1217,10 @@ QStringList PsiCon::recentGCList() const
 void PsiCon::recentGCAdd(const QString &str)
 {
 	QStringList recentList = recentGCList();
-	
 	// remove it if we have it
-	for(QStringList::Iterator it = recentList.begin(); it != recentList.end(); ++it) {
-		if(*it == str) {
-			recentList.remove(it);
+	foreach(const QString& s, recentList) {
+		if(s == str) {
+			recentList.removeAll(s);
 			break;
 		}
 	}
@@ -1211,7 +1230,7 @@ void PsiCon::recentGCAdd(const QString &str)
 
 	// trim the list if bigger than 10
 	while(recentList.count() > PsiOptions::instance()->getOption("options.muc.recent-joins.maximum").toInt()) {
-		recentList.remove(recentList.fromLast());
+		recentList.takeLast();
 	}
 	
 	PsiOptions::instance()->setOption("options.muc.recent-joins.jids", recentList);
@@ -1226,9 +1245,9 @@ void PsiCon::recentBrowseAdd(const QString &str)
 {
 	QStringList recentList = recentBrowseList();
 	// remove it if we have it
-	for(QStringList::Iterator it = recentList.begin(); it != recentList.end(); ++it) {
-		if(*it == str) {
-			recentList.remove(it);
+	foreach(const QString& s, recentList) {
+		if(s == str) {
+			recentList.removeAll(s);
 			break;
 		}
 	}
@@ -1238,7 +1257,7 @@ void PsiCon::recentBrowseAdd(const QString &str)
 
 	// trim the list if bigger than 10
 	while(recentList.count() > 10) {
-		recentList.remove(recentList.fromLast());
+		recentList.takeLast();
 	}
 	
 	PsiOptions::instance()->setOption("options.ui.service-discovery.recent-jids", recentList);
@@ -1252,9 +1271,9 @@ const QStringList & PsiCon::recentNodeList() const
 void PsiCon::recentNodeAdd(const QString &str)
 {
 	// remove it if we have it
-	for(QStringList::Iterator it = d->recentNodeList.begin(); it != d->recentNodeList.end(); ++it) {
-		if(*it == str) {
-			d->recentNodeList.remove(it);
+	foreach(const QString& s, d->recentNodeList) {
+		if(s == str) {
+			d->recentNodeList.removeAll(s);
 			break;
 		}
 	}
@@ -1264,7 +1283,7 @@ void PsiCon::recentNodeAdd(const QString &str)
 
 	// trim the list if bigger than 10
 	while(d->recentNodeList.count() > 10)
-		d->recentNodeList.remove(d->recentNodeList.fromLast());
+		d->recentNodeList.takeLast();
 }
 
 void PsiCon::proxy_settingsChanged()
