@@ -1,6 +1,6 @@
 /*
  * psitoolbar.h - the Psi toolbar class
- * Copyright (C) 2003  Michail Pishchagin
+ * Copyright (C) 2003-2008  Michail Pishchagin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,45 +21,38 @@
 #ifndef PSITOOLBAR_H
 #define PSITOOLBAR_H
 
-#include <q3toolbar.h>
+#include <QToolBar>
 
-#include "psiactionlist.h"
-#include "common.h" // Options + ToolbarPrefs
-
-class PsiCon;
 class QContextMenuEvent;
 
-class PsiToolBar : public Q3ToolBar
+class ToolbarPrefs;
+class PsiOptions;
+
+#include "psiactionlist.h"
+
+class PsiToolBar : public QToolBar
 {
 	Q_OBJECT
 
 public:
-	PsiToolBar(const QString& label, Q3MainWindow* mainWindow, PsiCon* psi);
+	PsiToolBar(const QString& base, QMainWindow* mainWindow, MetaActionList* actionList);
 	~PsiToolBar();
 
-	PsiActionList::ActionsType type() const;
-	void setType( PsiActionList::ActionsType );
-	void initialize( Options::ToolbarPrefs &, bool createUniqueActions );
+	void initialize();
+	void updateVisibility();
 
-	QString group() const;
-	int groupIndex() const;
-	void setGroup( QString group, int index );
-	
-	bool isCustomizeable() const;
-	void setCustomizeable( bool );
+	static void structToOptions(PsiOptions* options, const ToolbarPrefs& s);
 
-	bool isMoveable() const;
-	void setMoveable( bool );
-	
 signals:
-	void registerAction( IconAction * );
+	void customize();
 
 protected:
-	void contextMenuEvent(QContextMenuEvent *e);
+	void contextMenuEvent(QContextMenuEvent* e);
 
 private:
-	class Private;
-	Private *d;
+	MetaActionList* actionList_;
+	QAction* customizeAction_;
+	QString base_;
 };
 
 #endif
