@@ -6,7 +6,6 @@
 #include <QSystemTrayIcon>
 
 class PsiIcon;
-class TrayIcon; // old
 class QMenu;
 class QPoint;
 class QPixmap;
@@ -15,7 +14,7 @@ class PsiTrayIcon : public QObject
 {
 	Q_OBJECT
 public:
-	PsiTrayIcon(const QString &tip, QMenu *popup, bool old = true, QObject *parent=0);
+	PsiTrayIcon(const QString &tip, QMenu *popup, QObject *parent=0);
 	~PsiTrayIcon();
 
 	void setContextMenu(QMenu*);
@@ -44,9 +43,7 @@ protected:
 	QRgb pixelBlend(QRgb p1, QRgb p2);
 
 private:
-	bool old_;
 	PsiIcon* icon_;
-	TrayIcon* old_trayicon_; // old
 	QSystemTrayIcon* trayicon_;
 };
 
