@@ -1,6 +1,6 @@
 /*
  * advwidget.h - AdvancedWidget template class
- * Copyright (C) 2005  Michail Pishchagin
+ * Copyright (C) 2005-2007  Michail Pishchagin
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -38,19 +38,21 @@ public:
 	static bool stickToWindows();
 	static void setStickToWindows(bool val);
 
-	void restoreSavedGeometry(QRect savedGeometry);
+	QString geometryOptionPath() const;
+	void setGeometryOptionPath(const QString& optionPath);
+
+	void showWithoutActivation();
+
+	bool flashing() const;
 	void doFlash(bool on);
 
 #ifdef Q_OS_WIN
-	bool winEvent(MSG *msg);
+	bool winEvent(MSG* msg, long* result);
 #endif
 
 	void moveEvent(QMoveEvent *e);
+	void changeEvent(QEvent *event);
 
-	void preSetCaption();
-	void postSetCaption();
-
-	void windowActivationChange(bool oldstate);
 
 public:
 	class Private;
@@ -67,8 +69,10 @@ private:
 public:
 	AdvancedWidget(QWidget *parent = 0, Qt::WindowFlags f = 0)
 		: BaseClass(parent)
+		, gAdvWidget(0)
 	{
-		BaseClass::setWindowFlags(f);
+		if (f != 0)
+			BaseClass::setWindowFlags(f);
 		gAdvWidget = new GAdvancedWidget( this );
 	}
 
@@ -90,45 +94,72 @@ public:
 	static bool stickToWindows() { return GAdvancedWidget::stickToWindows(); }
 	static void setStickToWindows( bool val ) { GAdvancedWidget::setStickToWindows( val ); }
 
-	QRect saveableGeometry() const
+	QString geometryOptionPath() const
 	{
-		return QRect(BaseClass::pos(), BaseClass::size());
+		if (gAdvWidget)
+			return gAdvWidget->geometryOptionPath();
+		return QString();
 	}
 
-	virtual void restoreSavedGeometry(QRect savedGeometry)
+	void setGeometryOptionPath(const QString& optionPath)
 	{
-		gAdvWidget->restoreSavedGeometry(savedGeometry);
+		if (gAdvWidget)
+			gAdvWidget->setGeometryOptionPath(optionPath);
 	}
 
-	void doFlash( bool on )
+	bool flashing() const
 	{
-		gAdvWidget->doFlash( on );
+		if (gAdvWidget)
+			return gAdvWidget->flashing();
+		return false;
+	}
+
+	void showWithoutActivation()
+	{
+		if (gAdvWidget)
+			gAdvWidget->showWithoutActivation();
+	}
+
+	virtual void doFlash( bool on )
+	{
+		if (gAdvWidget)
+			gAdvWidget->doFlash( on );
 	}
 
 #ifdef Q_OS_WIN
-	bool winEvent( MSG *msg )
+	bool winEvent(MSG* msg, long* result)
 	{
-		return gAdvWidget->winEvent( msg );
+		if (gAdvWidget)
+			return gAdvWidget->winEvent(msg, result);
+		return BaseClass::winEvent(msg, result);
 	}
 #endif
 
 	void moveEvent( QMoveEvent *e )
 	{
-		gAdvWidget->moveEvent(e);
+		if (gAdvWidget)
+			gAdvWidget->moveEvent(e);
 	}
 
 	void setWindowTitle( const QString &c )
 	{
-		gAdvWidget->preSetCaption();
 		BaseClass::setWindowTitle( c );
-		gAdvWidget->postSetCaption();
+		windowTitleChanged();
 	}
 
 protected:
-	void windowActivationChange( bool oldstate )
+	virtual void windowTitleChanged()
 	{
-		gAdvWidget->windowActivationChange( oldstate );
-		BaseClass::windowActivationChange( oldstate );
+		doFlash(flashing());
+	}
+
+protected:
+	void changeEvent(QEvent *event)
+	{
+		if (gAdvWidget) {
+			gAdvWidget->changeEvent(event);
+		}
+		BaseClass::changeEvent(event);
 	}
 };
 
