@@ -26,7 +26,11 @@
 #include <QDomDocument>
 #include <QDomDocumentFragment>
 #include <QKeySequence>
-#include <QtCrypto>
+#include <QStringList>
+#include <QtDebug>
+#include "xmpp/base64/base64.h"
+
+using namespace XMPP;
 
 // FIXME: Helpers from xmpp_xmlcommon.h would be very appropriate for
 // void VariantTree::variantToElement(const QVariant& var, QDomElement& e)
@@ -62,9 +66,9 @@ VariantTree::~VariantTree()
  * @param rest part of the @a node after first dot
  * @return 
  */
-bool VariantTree::getKeyRest(QString node, QString &key, QString &rest)
+bool VariantTree::getKeyRest(const QString& node, QString &key, QString &rest)
 {
-	int idx = node.indexOf(".");
+	int idx = node.indexOf(QChar('.'));
 	if (idx != -1) {
 		key=node.left(idx);
 		rest=node.mid(idx+1);
@@ -83,7 +87,7 @@ but we don't want to have namespaces in the node names....
 	
 	but for now just allow ascii subset of this:
 	*/	
-	if (name == "") return false;
+	if (name.isEmpty()) return false;
 	int len = name.length();
 	QString other(".-_");
 	QChar ch = name[0];
@@ -111,7 +115,7 @@ void VariantTree::setValue(QString node, QVariant value)
 		{
 			if (values_.contains(key))
 			{
-				qWarning(qPrintable(QString("Error: Trying to add option node %1 but it already exists as a value").arg(key)));
+				qWarning() << QString("Error: Trying to add option node %1 but it already exists as a value").arg(key);
 				return;
 			}
 			//create a new tier
@@ -124,7 +128,7 @@ void VariantTree::setValue(QString node, QVariant value)
 		Q_ASSERT(isValidNodeName(node));
 		if (trees_.contains(node))
 		{
-			qWarning(qPrintable(QString("Error: Trying to add option value %1 but it already exists as a subtree").arg(node)));
+			qWarning() << QString("Error: Trying to add option value %1 but it already exists as a subtree").arg(node);
 			return;
 		}
 		values_[node]=value;
@@ -135,7 +139,7 @@ void VariantTree::setValue(QString node, QVariant value)
  * Get value at @a node
  * @return the value of @a node if @a node exists, otherwise VariantTree::missingValue
  */
-QVariant VariantTree::getValue(QString node) const
+QVariant VariantTree::getValue(const QString& node) const
 {
 	QString key,subnode;
 	if (getKeyRest(node, key, subnode)) {
@@ -201,17 +205,17 @@ bool VariantTree::isInternalNode(QString node) const
  */
 void VariantTree::setComment(QString node, QString comment)
 {
-	if (node.contains("."))
+	if (node.contains(QChar('.')))
 	{
 		//not this tier
-		QString key=node.left(node.indexOf("."));
-		QString subnode=node.remove(0,node.indexOf(".")+1);
+		QString key=node.left(node.indexOf(QChar('.')));
+		QString subnode=node.remove(0,node.indexOf(QChar('.'))+1);
 		Q_ASSERT(isValidNodeName(key));
 		if (!trees_.contains(key))
 		{
 			if (values_.contains(key))
 			{
-				qWarning(qPrintable(QString("Error: Trying to add option node %1 but it already exists as a value").arg(key)));
+				qWarning() << QString("Error: Trying to add option node %1 but it already exists as a value").arg(key);
 				return;
 			}
 			//create a new tier
@@ -232,11 +236,11 @@ void VariantTree::setComment(QString node, QString comment)
  */
 QString VariantTree::getComment(QString node) const
 {
-	if (node.contains("."))
+	if (node.contains(QChar('.')))
 	{
 		//not this tier
-		QString key=node.left(node.indexOf("."));
-		QString subnode=node.remove(0,node.indexOf(".")+1);
+		QString key=node.left(node.indexOf(QChar('.')));
+		QString subnode=node.remove(0,node.indexOf(QChar('.'))+1);
 		if (trees_.contains(key))
 		{
 			return trees_[key]->getComment(subnode);
@@ -264,8 +268,8 @@ QStringList VariantTree::nodeChildren(const QString& node, bool direct, bool int
 		// Go down further
 		QString subnode;
 		if (node.contains('.')) {
-			key = node.left(node.indexOf("."));
-			subnode = node.right(node.length() - node.indexOf(".") - 1);
+			key = node.left(node.indexOf(QChar('.')));
+			subnode = node.right(node.length() - node.indexOf(QChar('.')) - 1);
 		}
 		if (trees_.contains(key)) {
 			children = trees_[key]->nodeChildren(subnode,direct,internal_nodes);
@@ -307,7 +311,7 @@ void VariantTree::toXml(QDomDocument &doc, QDomElement& ele) const
 {
 	// Subtrees
 	foreach (QString node, trees_.keys()) {
-		Q_ASSERT(node != "");
+		Q_ASSERT(!node.isEmpty());
 		QDomElement nodeEle = doc.createElement(node);
 		trees_[node]->toXml(doc, nodeEle);
 		if (comments_.contains(node))
@@ -317,7 +321,7 @@ void VariantTree::toXml(QDomDocument &doc, QDomElement& ele) const
 	
 	// Values
 	foreach (QString child, values_.keys()) {
-		Q_ASSERT(child != "");
+		Q_ASSERT(!child.isEmpty());
 		QVariant var = values_[child];
 		QDomElement valEle = doc.createElement(child);
 		variantToElement(var,valEle);
@@ -342,7 +346,7 @@ void VariantTree::fromXml(const QDomElement &ele)
 	while (!child.isNull()) {
 		bool isunknown=false;
 		QString name = child.nodeName();
-		Q_ASSERT(name != "");
+		Q_ASSERT(!name.isEmpty());
 		if (!child.hasAttribute("type")) {
 			// Subnode
 			if ( !trees_.contains(name) )
@@ -444,7 +448,7 @@ QVariant VariantTree::elementToVariant(const QDomElement& e)
 		value = QByteArray();
 		for (QDomNode node = e.firstChild(); !node.isNull(); node = node.nextSibling()) {
 			if (node.isText()) {
-				value = QCA::Base64().stringToArray(node.toText().data()).toByteArray();
+				value = Base64::decode(node.toText().data());
 				break;
 			}
 		}
@@ -531,7 +535,7 @@ void VariantTree::variantToElement(const QVariant& var, QDomElement& e)
 		e.appendChild(height_element);
 	}
 	else if (type == "QByteArray") {
-		QDomText text = e.ownerDocument().createTextNode(QCA::Base64().arrayToString(var.toByteArray()));
+		QDomText text = e.ownerDocument().createTextNode(Base64::encode(var.toByteArray()));
 		e.appendChild(text);
 	}
 	else if (type == "QKeySequence") {
