@@ -33,6 +33,8 @@ namespace XMPP {
 }
 using namespace XMPP;
 
+class PsiAccount;
+
 class VCardFactory : public QObject
 {
 	Q_OBJECT
@@ -41,6 +43,7 @@ public:
 	static VCardFactory* instance();
 	const VCard *vcard(const Jid &);
 	void setVCard(const Jid &, const VCard &);
+	void setVCard(const PsiAccount* account, const VCard &v, QObject* obj = 0, const char* slot = 0);
 	JT_VCard *getVCard(const Jid &, Task *rootTask, const QObject *, const char *slot, bool cacheVCard = true);
 	
 signals:
@@ -50,6 +53,7 @@ protected:
 	void checkLimit(QString jid, VCard *vcard);
 	
 private slots:
+	void updateVCardFinished();
 	void taskFinished();
 	
 private:
@@ -60,6 +64,8 @@ private:
 	const int dictSize_;
 	QStringList vcardList_;
 	QMap<QString,VCard*> vcardDict_;
+
+	void saveVCard(const Jid &, const VCard &);
 };
 
 #endif
