@@ -21,24 +21,38 @@
 #ifndef XDATAWIDGET_H
 #define XDATAWIDGET_H
 
-#include <qwidget.h>
+#include <QWidget>
+#include <QList>
+#include <QString>
+#include <QVBoxLayout>
 
 #include "xmpp_xdata.h"
 
-using namespace XMPP;
+class XDataField;
 
 class XDataWidget : public QWidget
 {
+	Q_OBJECT
+
 public:
 	XDataWidget(QWidget *parent = 0, const char *name = 0);
 	~XDataWidget();
 
-	XData::FieldList fields() const;
-	void setFields(const XData::FieldList &);
+	void setForm(const XMPP::XData&);
+
+	XMPP::XData::FieldList fields() const;
+	void setFields(const XMPP::XData::FieldList &);
+
+	void setInstructions(const QString&);
+
+protected slots:
+	void linkActivated(const QString&);
 
 private:
-	class Private;
-	Private *d;
+	typedef QList<XDataField*> XDataFieldList;
+	XDataFieldList fields_;
+	QString instructions_;
+	QVBoxLayout* layout_;
 };
 
 #endif
