@@ -15,7 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  *
  */
 
@@ -39,7 +40,7 @@
 
    \sa qcaVersion for a runtime check.
 */
-#define QCA_VERSION 0x020000
+#define QCA_VERSION 0x020002
 
 #include <QString>
 #include <QStringList>
@@ -274,7 +275,8 @@ QCA_EXPORT bool insertProvider(Provider *p, int priority = 0);
    if that provider supports the algorithm.
    - if the provider with the lowest priority number doesn't support 
    the required algorithm, the provider with the next lowest priority number
-   will be tried,and so on through to the provider with the largest priority number
+   will be tried, and so on through to the provider with the largest priority
+   number
    - if none of the plugin providers support the required algorithm, then
    the default (built-in) provider will be tried.
 
